##  Rejecting Discovered Items
You can reject fact sheets that you do not want to create. This helps you keep your list short and find new fact sheets quickly.
To reject a fact sheet, select the item to open the right-side pane and choose Reject Item at the bottom.
